@@ -1,11 +1,12 @@
 import timeside
+import timeside.core
 
 def list_processors(interface, prefix=""):
     print prefix + interface.__name__
     subinterfaces = interface.__subclasses__()
     for i in subinterfaces:
         list_processors(i, prefix + "  ")
-    processors = timeside.processors(interface, False)
+    processors = timeside.core.processors(interface, False)
     for p in processors:
         print prefix + "  %s [%s]" % (p.__name__, p.id())
 
