@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 #
+# Copyright (c) 2009-2013 Parisson SARL
 # Copyright (c) 2009 Olivier Guilyardi <olivier@samalyse.com>
 #
 # This file is part of TimeSide.
@@ -42,8 +43,15 @@ class MetaProcessor(MetaComponent):
         if new_class in implementations(IProcessor):
             id = str(new_class.id())
             if _processors.has_key(id):
-                raise ApiError("%s and %s have the same id: '%s'"
-                    % (new_class.__name__, _processors[id].__name__, id))
+                # Doctest test can duplicate a processor
+                # This can be identify by the conditon "module == '__main__'"
+                if new_class.__module__ == '__main__':
+                    new_class = _processors[id]
+                elif _processors[id].__module__ == '__main__':
+                    pass
+                else:
+                    raise ApiError("%s and %s have the same id: '%s'"
+                        % (new_class.__name__, _processors[id].__name__, id))
             if not MetaProcessor.valid_id.match(id):
                 raise ApiError("%s has a malformed id: '%s'"
                     % (new_class.__name__, id))
@@ -61,39 +69,60 @@ class Processor(Component):
     implements(IProcessor)
 
     @interfacedoc
-    def setup(self, channels=None, samplerate=None, blocksize=None, totalframes=None):
-        self.input_channels     = channels
-        self.input_samplerate   = samplerate
-        self.input_blocksize    = blocksize
-        self.input_totalframes  = totalframes
+    def setup(self, channels=None, samplerate=None, blocksize=None,
+              totalframes=None):
+        self.source_channels     = channels
+        self.source_samplerate   = samplerate
+        self.source_blocksize    = blocksize
+        self.source_totalframes  = totalframes
+
+        # If empty Set default values for input_* attributes
+        # may be setted by the processor during __init__()
+        if not hasattr(self, 'input_channels'):
+            self.input_channels = self.source_channels
+        if not hasattr(self, 'input_samplerate'):
+            self.input_samplerate = self.source_samplerate
+        if not hasattr(self, 'input_blocksize'):
+            self.input_blocksize = self.source_blocksize
+        if not hasattr(self, 'input_stepsize'):
+            self.input_stepsize = self.source_blocksize
+
 
     # default channels(), samplerate() and blocksize() implementations returns
-    # the input characteristics, but processors may change this behaviour by
+    # the source characteristics, but processors may change this behaviour by
     # overloading those methods
     @interfacedoc
     def channels(self):
-        return self.input_channels
+        return self.source_channels
 
     @interfacedoc
     def samplerate(self):
-        return self.input_samplerate
+        return self.source_samplerate
 
     @interfacedoc
     def blocksize(self):
-        return self.input_blocksize
+        return self.source_blocksize
 
     @interfacedoc
     def totalframes(self):
-        return self.input_totalframes
+        return self.source_totalframes
 
     @interfacedoc
     def process(self, frames, eod):
         return frames, eod
 
+    @interfacedoc
+    def post_process(self):
+        pass
+
     @interfacedoc
     def release(self):
         pass
 
+    @interfacedoc
+    def mediainfo(self):
+        return self.source_mediainfo
+
     def __del__(self):
         self.release()
 
@@ -214,12 +243,17 @@ class ProcessPipe(object):
 
         last = source
 
+        from timeside.analyzer.core import AnalyzerResultContainer
+        self._results = AnalyzerResultContainer()
+
         # setup/reset processors and configure properties throughout the pipe
         for item in items:
             item.setup(channels = last.channels(),
                        samplerate = last.samplerate(),
                        blocksize = last.blocksize(),
                        totalframes = last.totalframes())
+            item.source_mediainfo = source.mediainfo()
+            item._results = self._results
             last = item
 
         # now stream audio data along the pipe
@@ -229,7 +263,18 @@ class ProcessPipe(object):
             for item in items:
                 frames, eod = item.process(frames, eod)
 
+        for item in items:
+            item.post_process()
+
         for item in items:
             item.release()
 
         return self
+
+    @property
+    def results(self):
+        """
+        Results Container for all the analyzers of the Pipe process
+        """
+        if hasattr(self, '_results'):
+            return self._results
\ No newline at end of file
