@@ -22,16 +22,21 @@
 # along with TimeSide.  If not, see <http://www.gnu.org/licenses/>.
 
 # Authors: Paul Brossier <piem@piem.org>
-#          Guilaume Pellerin <yomguy@parisson.com>
+# Guillaume Pellerin <yomguy@parisson.com>
 
 from timeside.core import Processor, implements, interfacedoc
 from timeside.api import IDecoder
 from timeside.tools import *
 
 import Queue
+from gst import _gst as gst
+from numpy import int64, uint64
+
 
 GST_APPSINK_MAX_BUFFERS = 10
 QUEUE_SIZE = 10
+GST_DISCOVER_TIMEOUT = 5000000000L
+
 
 class FileDecoder(Processor):
     """ gstreamer-based decoder """
@@ -52,7 +57,19 @@ class FileDecoder(Processor):
     def id():
         return "gstreamerdec"
 
-    def __init__(self, uri):
+    def __init__(self, uri, start = 0, duration = None):
+        '''
+            Construct a new FileDecoder
+
+            Parameters
+            ----------
+            uri: uri of the media
+            start : float
+                start time of the segment in seconds
+            duration : float
+                duration of the segment in seconds
+        '''
+
         # is this a file?
         import os.path
         if os.path.exists(uri):
@@ -60,13 +77,40 @@ class FileDecoder(Processor):
             uri = os.path.abspath(uri)
             # and make a uri of it
             from urllib import quote
-            self.uri = 'file://'+quote(uri)
+            self.uri = 'file://' + quote(uri)
         elif '://' in uri:
             self.uri = uri
         else:
-            raise IOError, 'File not found!'
+            raise IOError('File not found!')
 
-    def setup(self, channels = None, samplerate = None, blocksize = None):
+        self.uri_start = float(start)
+        if duration:
+            self.uri_duration = float(duration)
+        else:
+            self.uri_duration = duration
+
+        if start==0 and duration is None:
+            self.is_segment = False
+        else:
+            self.is_segment = True
+
+    def set_uri_default_duration(self):
+        # Set the duration from the length of the file
+        from gst.pbutils import Discoverer
+        from glib import GError
+        #import gobject
+        uri_discoverer = Discoverer(GST_DISCOVER_TIMEOUT)
+        try:
+            uri_info = uri_discoverer.discover_uri(self.uri)
+        except  GError as e:
+            raise IOError(e)
+        self.uri_duration = (uri_info.get_duration() / float(gst.SECOND) -
+                            self.uri_start)
+
+    def setup(self, channels=None, samplerate=None, blocksize=None):
+
+        if self.uri_duration is None:
+            self.set_uri_default_duration()
 
         # a lock to wait wait for gstreamer thread to be ready
         import threading
@@ -74,17 +118,35 @@ class FileDecoder(Processor):
         self.discovered = False
 
         # the output data format we want
-        if blocksize:   self.output_blocksize  = blocksize
-        if samplerate:  self.output_samplerate = int(samplerate)
-        if channels:    self.output_channels   = int(channels)
+        if blocksize:
+            self.output_blocksize = blocksize
+        if samplerate:
+            self.output_samplerate = int(samplerate)
+        if channels:
+            self.output_channels = int(channels)
 
-        uri = self.uri
+        if self.is_segment:
+            # Create the pipe with Gnonlin gnlurisource
+            self.pipe = ''' gnlurisource uri={uri}
+                            start=0
+                            duration={uri_duration}
+                            media-start={uri_start}
+                            media-duration={uri_duration}
+                            ! audioconvert name=audioconvert
+                            ! audioresample
+                            ! appsink name=sink sync=False async=True
+                            '''.format(uri = self.uri,
+                                       uri_start = uint64(round(self.uri_start * gst.SECOND)),
+                                       uri_duration = int64(round(self.uri_duration * gst.SECOND)))
+                                       # convert uri_start and uri_duration to nanoseconds
+        else:
+            # Create the pipe with standard Gstreamer uridecodbin
+            self.pipe = ''' uridecodebin name=uridecodebin uri={uri}
+                           ! audioconvert name=audioconvert
+                           ! audioresample
+                           ! appsink name=sink sync=False async=True
+                           '''.format(uri = self.uri)
 
-        self.pipe = ''' uridecodebin name=uridecodebin uri=%(uri)s
-                  ! audioconvert name=audioconvert
-                  ! audioresample
-                  ! appsink name=sink sync=False async=True
-                  ''' % locals()
         self.pipeline = gst.parse_launch(self.pipe)
 
         if self.output_channels:
@@ -118,6 +180,7 @@ class FileDecoder(Processor):
         self.queue = Queue.Queue(QUEUE_SIZE)
 
         import threading
+
         class MainloopThread(threading.Thread):
             def __init__(self, mainloop):
                 threading.Thread.__init__(self)
@@ -140,11 +203,11 @@ class FileDecoder(Processor):
 
         self.discovered_cond.acquire()
         while not self.discovered:
-          #print 'waiting'
-          self.discovered_cond.wait()
+            #print 'waiting'
+            self.discovered_cond.wait()
         self.discovered_cond.release()
 
-        if not hasattr(self,'input_samplerate'):
+        if not hasattr(self, 'input_samplerate'):
             if hasattr(self, 'error_msg'):
                 raise IOError(self.error_msg)
             else:
@@ -178,10 +241,10 @@ class FileDecoder(Processor):
         if "audio" in caps.to_string():
             self.input_samplerate = caps[0]["rate"]
             if not self.output_samplerate:
-              self.output_samplerate = self.input_samplerate
+                self.output_samplerate = self.input_samplerate
             self.input_channels = caps[0]["channels"]
             if not self.output_channels:
-              self.output_channels = self.input_channels
+                self.output_channels = self.input_channels
             self.input_duration = length / 1.e9
             self.input_totalframes = int(self.input_duration * self.input_samplerate)
             if "x-raw-float" in caps.to_string():
@@ -226,10 +289,10 @@ class FileDecoder(Processor):
             new_block = self.last_buffer[:self.output_blocksize]
             self.last_buffer = self.last_buffer[self.output_blocksize:]
             #print 'queueing', new_block.shape, 'remaining', self.last_buffer.shape
-            self.queue.put( [new_block, False ] )
+            self.queue.put([new_block, False])
 
     @interfacedoc
-    def process(self, frames = None, eod = False):
+    def process(self, frames=None, eod=False):
         buf = self.queue.get()
         if buf == gst.MESSAGE_EOS:
             return self.last_buffer, True
@@ -238,7 +301,7 @@ class FileDecoder(Processor):
 
     @interfacedoc
     def channels(self):
-        return  self.output_channels
+        return self.output_channels
 
     @interfacedoc
     def samplerate(self):
@@ -260,6 +323,14 @@ class FileDecoder(Processor):
     def release(self):
         pass
 
+    @interfacedoc
+    def mediainfo(self):
+        return dict(uri=self.uri,
+                    duration=self.uri_duration,
+                    start=self.uri_start,
+                    is_segment=self.is_segment,
+                    samplerate=self.input_samplerate)
+
     def __del__(self):
         self.release()
 
@@ -286,4 +357,3 @@ class FileDecoder(Processor):
     def metadata(self):
         # TODO check
         return self.tags
-
