@@ -273,6 +273,7 @@ class WaveformImage(object):
     def release(self):
         pass
 
+
 class WaveformImageJoyContour(WaveformImage):
 
     def __init__(self, image_width, image_height, nframes, samplerate,
@@ -325,7 +326,6 @@ class WaveformImageJoyContour(WaveformImage):
         for i in range(0,self.ndiv):
             self.previous_x, self.previous_y = None, None
 
-            #bright_color = 255
             bright_color = int(255*(1-float(i)/(self.ndiv*2)))
             bright_color = 255-bright_color+self.color_offset
             #line_color = self.color_lookup[int(self.centroids[j]*255.0)]
@@ -335,11 +335,9 @@ class WaveformImageJoyContour(WaveformImage):
             #contour = contour*(1.0-float(i)/self.ndiv)
             #contour = contour*(1-float(i)/self.ndiv)
 
-            # Cosine
+            # Scaled
             contour = contour*numpy.arccos(float(i)/self.ndiv)*2/numpy.pi
             #contour = self.contour*(1-float(i)*numpy.arccos(float(i)/self.ndiv)*2/numpy.pi/self.ndiv)
-
-            # Negative Sine
             #contour = contour + ((1-contour)*2/numpy.pi*numpy.arcsin(float(i)/self.ndiv))
 
             curve = (height-1)*contour
@@ -391,6 +389,7 @@ class WaveformImageJoyContour(WaveformImage):
     def release(self):
         pass
 
+
 class WaveformImageSimple(object):
     """ Builds a PIL image representing a waveform of the audio stream.
     Adds pixels iteratively thanks to the adapter providing fixed size frame buffers.
@@ -488,6 +487,7 @@ class WaveformImageSimple(object):
     def release(self):
         pass
 
+
 class SpectrogramImage(object):
     """ Builds a PIL image representing a spectrogram of the audio stream (level vs. frequency vs. time).
     Adds pixels iteratively thanks to the adapter providing fixed size frame buffers."""
@@ -569,6 +569,7 @@ class SpectrogramImage(object):
     def release(self):
         pass
 
+
 class Noise(object):
     """A class that mimics audiolab.sndfile but generates noise instead of reading
     a wave file. Additionally it can be told to have a "broken" header and thus crashing
@@ -619,37 +620,56 @@ def downsample(vector, factor):
 
 
 def smooth(x, window_len=10, window='hanning'):
-    """smooth the data using a window with requested size.
+    """
+    Smooth the data using a window with requested size.
 
     This method is based on the convolution of a scaled window with the signal.
     The signal is prepared by introducing reflected copies of the signal
     (with the window size) in both ends so that transient parts are minimized
     in the begining and end part of the output signal.
 
-    input:
-        x: the input signal
-        window_len: the dimension of the smoothing window
-        window: the type of window from 'flat', 'hanning', 'hamming', 'bartlett', 'blackman'
-            flat window will produce a moving average smoothing.
+    Parameters
+    ----------
+    x : numpy.array
+        the input signal
+    window_len : int
+        the dimension of the smoothing window
+    window : str
+        the type of window from 'flat', 'hanning', 'hamming', 'bartlett', 'blackman'
+        flat window will produce a moving average smoothing.
 
-    output:
-        the smoothed signal
+    Returns
+    -------
+    The smoothed signal
 
-    example:
-
-    import numpy as np
-    t = numpy.linspace(-2,2,0.1)
-    x = numpy.sin(t)+numpy.random.randn(len(t))*0.1
-    y = smooth(x)
-
-    see also:
+    See Also
+    --------
 
     numpy.hanning, numpy.hamming, numpy.bartlett, numpy.blackman, numpy.convolve
     scipy.signal.lfilter
 
-    TODO: the window parameter could be the window itself if an array instead of a string
+
+    Examples
+    --------
+
+    >>> import numpy as np
+    >>> from timeside.grapher import smooth
+    >>> t = np.arange(-2,2,0.1)
+    >>> x = np.sin(t)+np.random.randn(len(t))*0.1
+    >>> y = smooth(x)
+    >>> import matplotlib.pyplot as plt
+    >>> plt.plot(x) # doctest: +ELLIPSIS
+    [<matplotlib.lines.Line2D object at 0x...>]
+    >>> plt.plot(y) # doctest: +ELLIPSIS
+    [<matplotlib.lines.Line2D object at 0x...>]
+    >>> plt.legend(['Source signal', 'Smoothed signal']) # doctest: +ELLIPSIS
+    <matplotlib.legend.Legend object at 0x...>
+    >>> plt.show() # doctest: +SKIP
     """
 
+    # TODO: the window parameter could be the window itself if an array instead of a string
+
+
     if x.ndim != 1:
         raise ValueError, "smooth only accepts 1 dimension arrays."
 
@@ -672,6 +692,7 @@ def smooth(x, window_len=10, window='hanning'):
     y = numpy.convolve(w/w.sum(), s, mode='same')
     return y[window_len-1:-window_len+1]
 
+
 def reduce_opacity(im, opacity):
     """Returns an image with reduced opacity."""
     assert opacity >= 0 and opacity <= 1
@@ -684,6 +705,7 @@ def reduce_opacity(im, opacity):
     im.putalpha(alpha)
     return im
 
+
 def im_watermark(im, inputtext, font=None, color=None, opacity=.6, margin=(30,30)):
     """
     imprints a PIL image with the indicated text in lower-right corner
@@ -698,3 +720,8 @@ def im_watermark(im, inputtext, font=None, color=None, opacity=.6, margin=(30,30
     if opacity != 1:
         textlayer = reduce_opacity(textlayer,opacity)
     return Image.composite(textlayer, im, textlayer)
+
+
+if __name__ == "__main__":
+    import doctest
+    doctest.testmod()
\ No newline at end of file
